@@ -209,18 +209,15 @@ SKGraph* Serializer::deserializeGraph(const QDomElement &element) {
 		return graph;
 	} else if(type == QLatin1String("custom")) {
 		int err=0;
-		int ncliques;
 		int sizeX;
 		int sizeY;
 		int sizeZ;
 		if (orderStr != QStringLiteral("Mathdoku")) {
-		    ncliques = readInt(element,QStringLiteral("ncliques"), &err);
 		    sizeX = readInt(element,QStringLiteral("sizeX"),&err);
 		    sizeY = readInt(element,QStringLiteral("sizeY"),&err);
 		}
 		else {
 		    // In Mathdoku, there are row and column groups only.
-		    ncliques = 2 * order;
 		    sizeX = order;
 		    sizeY = order;
 		}
@@ -243,7 +240,7 @@ SKGraph* Serializer::deserializeGraph(const QDomElement &element) {
 
 		auto* graph = new SKGraph(order, TypeCustom);
 		graph->initCustom(name, puzzleType, order,
-			    sizeX, sizeY, sizeZ, ncliques);
+			    sizeX, sizeY, sizeZ);
 
 		QDomNode child = element.firstChild();
 		while (!child.isNull()) {
@@ -296,7 +293,7 @@ bool Serializer::deserializeClique(SKGraph * graph, const QString & size,
     }
 
     const QStringList  splitData = text.split(QStringLiteral(" "), Qt::SkipEmptyParts);
-    QVector<int> data;
+    QList<int> data;
     data.clear();
     for (const QString &s : splitData) {
 	--cellCount;
@@ -315,7 +312,7 @@ bool Serializer::deserializeCage(SKGraph * graph, const QDomElement & e) {
     CageOperator op = (CageOperator) (e.attribute(QStringLiteral("operator")).toInt());
     int target      = e.attribute(QStringLiteral("value")).toInt();
     int size        = 0;
-    QVector<int> cage;
+    QList<int> cage;
     if(! sizeStr.isNull()) {
 	size = sizeStr.toInt();
     }
@@ -397,6 +394,7 @@ HistoryEvent Serializer::deserializeComplexHistoryEvent(const QDomElement /*elem
 }
 
 SKGraph *Serializer::loadCustomShape(const QUrl& url, QWidget* window, QString& errorMsg) {
+	Q_UNUSED(window);
 	if ( url.isEmpty() ) {
 		errorMsg = i18n("Unable to download file: URL is empty.");
 		return nullptr;
@@ -409,12 +407,10 @@ SKGraph *Serializer::loadCustomShape(const QUrl& url, QWidget* window, QString&
 		return nullptr;
 	}
 
-	int errorLine;
-	int errorColumn;
-	QString errorMessage;
-	if(!doc.setContent(&file, &errorMessage, &errorLine, &errorColumn)) {
-		qDebug() << "Error " << errorMessage << " from line " << errorLine << ":" << errorColumn << " from file " << url.toString();
-		errorMsg = i18n("Cannot read XML file on line %1", errorLine);
+	const QDomDocument::ParseResult parseResult = doc.setContent(&file);
+	if (!parseResult) {
+		qDebug() << "Error " << parseResult.errorMessage << " from line " << parseResult.errorLine << ":" << parseResult.errorColumn << " from file " << url.toString();
+		errorMsg = i18n("Cannot read XML file on line %1", parseResult.errorLine);
 
 		return nullptr;
 	}
@@ -445,9 +441,9 @@ Game Serializer::load(const QUrl& url, QWidget* window, QString& errorMsg) {
 		return Game();
 	}
 
-	int errorLine;
-    if(!doc.setContent(downloadJob->data(), nullptr, &errorLine)) {
-		errorMsg = i18n("Cannot read XML file on line %1", errorLine);
+	const QDomDocument::ParseResult parseResult = doc.setContent(downloadJob->data());
+	if (!parseResult) {
+		errorMsg = i18n("Cannot read XML file on line %1", parseResult.errorLine);
 		return Game();
 	}
 
@@ -531,7 +527,6 @@ bool Serializer::serializeGraph(QDomElement &parent, const SKGraph *graph)
 
 	if(type == TypeCustom) {
 	    element.setAttribute(QStringLiteral("name"), graph->name());
-	    element.setAttribute(QStringLiteral("ncliques"), (int) graph->cliqueCount());
 	    element.setAttribute(QStringLiteral("sizeX"), graph->sizeX());
 	    element.setAttribute(QStringLiteral("sizeY"), graph->sizeY());
 	    element.setAttribute(QStringLiteral("sizeZ"), graph->sizeZ());
@@ -572,7 +567,7 @@ bool Serializer::serializeGraph(QDomElement &parent, const SKGraph *graph)
 	    // Add cages if this is a Mathdoku or Killer Sudoku puzzle.
 	    for (int n = 0; n < graph->cageCount(); n++) {
 		QDomElement e = parent.ownerDocument().createElement(QStringLiteral("cage"));
-		const QVector<int> cage = graph->cage(n);
+		const QList<int> cage = graph->cage(n);
 		e.setAttribute(QStringLiteral("operator"), graph->cageOperator(n));
 		e.setAttribute(QStringLiteral("value"), graph->cageValue(n));
 		e.setAttribute(QStringLiteral("size"), cage.size());
@@ -607,8 +602,8 @@ bool Serializer::serializeHistory(QDomElement& parent, const Game& game) {
 bool Serializer::serializeHistoryEvent(QDomElement& parent, const HistoryEvent& event) {
 	QDomElement element;
 
-	const QVector<int>& indices = event.cellIndices();
-	const QVector<CellInfo>& changes = event.cellChanges();
+	const QList<int>& indices = event.cellIndices();
+	const QList<CellInfo>& changes = event.cellChanges();
 
 	if(indices.count() == 0) {
 		return true;
